@@ -2,6 +2,7 @@ package main
 
 import (
 	"bytes"
+	"encoding/json"
 	"fmt"
 	"os"
 	"sort"
@@ -52,15 +53,14 @@ schedule = "daily"
 	assert.Nil(t, err)
 
 	// Test that errors from getScheduleJobs are passed through
-	_, _, _, notFoundErr := getRemovableScheduleJobs(parsedConfig, commandLineFlags{name: "non-existent"})
-	assert.EqualError(t, notFoundErr, "profile 'non-existent' not found")
+	_, _, notFoundErr := getRemovableScheduleJobs(parsedConfig, commandLineFlags{name: "non-existent"})
+	assert.ErrorIs(t, notFoundErr, config.ErrNotFound)
 
 	// Test that declared and declarable job configs are returned
-	_, profile, schedules, err := getRemovableScheduleJobs(parsedConfig, commandLineFlags{name: "default"})
+	_, schedules, err := getRemovableScheduleJobs(parsedConfig, commandLineFlags{name: "default"})
 	assert.Nil(t, err)
-	assert.NotNil(t, profile)
 	assert.NotEmpty(t, schedules)
-	assert.Len(t, schedules, len(profile.SchedulableCommands()))
+	assert.Len(t, schedules, len(config.NewProfile(parsedConfig, "test").SchedulableCommands()))
 
 	declaredCount := 0
 
@@ -91,13 +91,13 @@ schedule = "daily"
 	assert.Nil(t, err)
 
 	// Test that non-existent profiles causes an error
-	_, _, _, notFoundErr := getScheduleJobs(cfg, commandLineFlags{name: "non-existent"})
-	assert.EqualError(t, notFoundErr, "profile 'non-existent' not found")
+	_, _, notFoundErr := getProfileScheduleJobs(cfg, commandLineFlags{name: "non-existent"})
+	assert.ErrorIs(t, notFoundErr, config.ErrNotFound)
 
 	// Test that non-existent schedule causes no error at first
 	{
 		flags := commandLineFlags{name: "other"}
-		_, _, schedules, err := getScheduleJobs(cfg, flags)
+		_, schedules, err := getProfileScheduleJobs(cfg, flags)
 		assert.Nil(t, err)
 
 		err = requireScheduleJobs(schedules, flags)
@@ -107,7 +107,7 @@ schedule = "daily"
 	// Test that only declared job configs are returned
 	{
 		flags := commandLineFlags{name: "default"}
-		_, profile, schedules, err := getScheduleJobs(cfg, flags)
+		profile, schedules, err := getProfileScheduleJobs(cfg, flags)
 		assert.Nil(t, err)
 
 		err = requireScheduleJobs(schedules, flags)
@@ -136,26 +136,33 @@ _ = 0
 _ = 0
 `
 	allProfiles := []string{"default", "2nd", "3rd"}
+	allGroups := []string{"others", "default"}
+	allProfilesAndGroups := append(allProfiles, allGroups...)
 
 	cfg, err := config.Load(bytes.NewBufferString(testConfig), "toml")
 	assert.Nil(t, err)
 	for _, p := range allProfiles {
 		assert.True(t, cfg.HasProfile(p))
 	}
+	for _, g := range allGroups {
+		assert.True(t, cfg.HasProfileGroup(g))
+	}
 
 	// Select --all
-	assert.ElementsMatch(t, allProfiles, selectProfiles(cfg, commandLineFlags{}, []string{"--all"}))
-
-	// Select profiles of group
-	assert.ElementsMatch(t, []string{"2nd", "3rd"}, selectProfiles(cfg, commandLineFlags{name: "others"}, nil))
+	assert.ElementsMatch(t, allProfilesAndGroups, selectProfilesAndGroups(cfg, commandLineFlags{}, []string{"--all"}))
 
 	// Select profiles by name
 	for _, p := range allProfiles {
-		assert.ElementsMatch(t, []string{p}, selectProfiles(cfg, commandLineFlags{name: p}, nil))
+		assert.ElementsMatch(t, []string{p}, selectProfilesAndGroups(cfg, commandLineFlags{name: p}, nil))
+	}
+
+	// Select groups by name
+	for _, g := range allGroups {
+		assert.ElementsMatch(t, []string{g}, selectProfilesAndGroups(cfg, commandLineFlags{name: g}, nil))
 	}
 
 	// Select non-existing profile or group
-	assert.ElementsMatch(t, []string{"non-existing"}, selectProfiles(cfg, commandLineFlags{name: "non-existing"}, nil))
+	assert.ElementsMatch(t, []string{"non-existing"}, selectProfilesAndGroups(cfg, commandLineFlags{name: "non-existing"}, nil))
 }
 
 func TestFlagsForProfile(t *testing.T) {
@@ -234,12 +241,28 @@ func TestGenerateCommand(t *testing.T) {
 		assert.Contains(t, ref, "generating nested section")
 	})
 
-	t.Run("--json-schema", func(t *testing.T) {
+	t.Run("--json-schema global", func(t *testing.T) {
 		buffer.Reset()
-		assert.NoError(t, generateCommand(buffer, contextWithArguments([]string{"--json-schema"})))
+		assert.NoError(t, generateCommand(buffer, contextWithArguments([]string{"--json-schema", "global"})))
 		ref := buffer.String()
-		assert.Contains(t, ref, "\"profiles\":")
+		assert.Contains(t, ref, `"$schema"`)
+		assert.Contains(t, ref, "/jsonschema/config-1.json")
 		assert.Contains(t, ref, "/jsonschema/config-2.json")
+
+		decoder := json.NewDecoder(strings.NewReader(ref))
+		content := make(map[string]any)
+		assert.NoError(t, decoder.Decode(&content))
+		assert.Contains(t, content, `$schema`)
+	})
+
+	t.Run("--json-schema no-option", func(t *testing.T) {
+		buffer.Reset()
+		assert.Error(t, generateCommand(buffer, contextWithArguments([]string{"--json-schema"})))
+	})
+
+	t.Run("--json-schema invalid-option", func(t *testing.T) {
+		buffer.Reset()
+		assert.Error(t, generateCommand(buffer, contextWithArguments([]string{"--json-schema", "_invalid_"})))
 	})
 
 	t.Run("--json-schema v1", func(t *testing.T) {
@@ -249,6 +272,14 @@ func TestGenerateCommand(t *testing.T) {
 		assert.Contains(t, ref, "/jsonschema/config-1.json")
 	})
 
+	t.Run("--json-schema v2", func(t *testing.T) {
+		buffer.Reset()
+		assert.NoError(t, generateCommand(buffer, contextWithArguments([]string{"--json-schema", "v2"})))
+		ref := buffer.String()
+		assert.Contains(t, ref, "\"profiles\":")
+		assert.Contains(t, ref, "/jsonschema/config-2.json")
+	})
+
 	t.Run("--json-schema --version 0.13 v1", func(t *testing.T) {
 		buffer.Reset()
 		assert.NoError(t, generateCommand(buffer, contextWithArguments([]string{"--json-schema", "--version", "0.13", "v1"})))
@@ -289,7 +320,7 @@ schedule backup@default:
     at:                   daily
     permission:           auto
     command-output:       auto
-    priority:             background
+    priority:             standard
     lock-mode:            default
     capture-environment:  RESTIC_*
 
@@ -297,7 +328,7 @@ schedule check@default:
     at:                   weekly
     permission:           auto
     command-output:       auto
-    priority:             background
+    priority:             standard
     lock-mode:            default
     capture-environment:  RESTIC_*
 `)
