@@ -265,7 +265,7 @@ func newSchemaBool() *schemaTypeBase {
 
 type schemaObject struct {
 	schemaTypeBase
-	AdditionalProperties bool                  `json:"additionalProperties"`
+	AdditionalProperties any                   `json:"additionalProperties,omitempty"`
 	PatternProperties    map[string]SchemaType `json:"patternProperties,omitempty"`
 	Properties           map[string]SchemaType `json:"properties,omitempty"`
 	Required             []string              `json:"required,omitempty"`
@@ -274,9 +274,10 @@ type schemaObject struct {
 
 func newSchemaObject() *schemaObject {
 	return withBaseType(&schemaObject{
-		PatternProperties: make(map[string]SchemaType),
-		Properties:        make(map[string]SchemaType),
-		DependentRequired: make(map[string][]string),
+		AdditionalProperties: false,
+		PatternProperties:    make(map[string]SchemaType),
+		Properties:           make(map[string]SchemaType),
+		DependentRequired:    make(map[string][]string),
 	}, "object")
 }
 
@@ -297,6 +298,15 @@ func (s *schemaObject) verify() (err error) {
 			err = fmt.Errorf("type of %q in properties is undefined", name)
 		}
 	}
+	if err == nil {
+		switch s.AdditionalProperties.(type) {
+		case nil:
+		case bool:
+		case SchemaType:
+		default:
+			err = fmt.Errorf("additionalProperties must be nil, boolean or SchemaType")
+		}
+	}
 	if err == nil {
 		err = s.schemaTypeBase.verify()
 	}
@@ -438,6 +448,9 @@ func internalWalkTypes(into map[SchemaType]bool, current SchemaType, callback fu
 			for name, property := range t.PatternProperties {
 				t.PatternProperties[name] = internalWalkTypes(into, property, callback)
 			}
+			if item, ok := t.AdditionalProperties.(SchemaType); ok {
+				t.AdditionalProperties = internalWalkTypes(into, item, callback)
+			}
 		case *schemaArray:
 			t.Items = internalWalkTypes(into, t.Items, callback)
 		case *schemaTypeList:
