@@ -141,7 +141,7 @@ func scheduleToConfig(sched *config.Schedule) *schedule.Config {
 		Permission:              sched.Permission,
 		WorkingDirectory:        "",
 		Command:                 "",
-		Arguments:               []string{},
+		Arguments:               schedule.NewCommandArguments(nil),
 		Environment:             sched.Environment,
 		JobDescription:          "",
 		TimerDescription:        "",
