@@ -4,7 +4,7 @@ type Config struct {
 	ProfileName      string
 	CommandName      string
 	Command          string
-	Arguments        []string
+	Arguments        string
 	WorkingDirectory string
 	JobDescription   string
 }
