@@ -1728,3 +1728,37 @@ func TestCopySnapshot(t *testing.T) {
 	cmd := wrapper.prepareCommand("copy", args, false)
 	assert.Equal(t, []string{"copy", "snapshot1", "snapshot2"}, cmd.args)
 }
+
+func TestPrepareCommandShouldEscapeBinary(t *testing.T) {
+	if platform.IsWindows() {
+		t.Skip("not supported on Windows")
+	}
+	t.Parallel()
+
+	profile := config.NewProfile(&config.Config{}, "name")
+	ctx := &Context{
+		binary:  "/full path to/restic",
+		profile: profile,
+		command: "backup",
+	}
+	wrapper := newResticWrapper(ctx)
+	args := shell.NewArgs()
+	cmd := wrapper.prepareCommand("backup", args, false)
+	assert.Equal(t, `/full\ path\ to/restic`, cmd.command)
+}
+
+func TestRunUnlockWithCommandLineFlags(t *testing.T) {
+	t.Parallel()
+
+	profile := config.NewProfile(&config.Config{}, "TestProfile")
+	ctx := &Context{
+		binary:  "restic",
+		profile: profile,
+		command: constants.CommandForget,
+		request: Request{arguments: []string{"some-string", "--some-flag", "-n"}},
+	}
+	wrapper := newResticWrapper(ctx)
+	args := profile.GetCommandFlags(constants.CommandUnlock)
+	cmd := wrapper.prepareCommand(constants.CommandUnlock, args, false)
+	assert.Equal(t, []string{"unlock"}, cmd.args)
+}
